==> rpp-6.1.1.tar.gz: rpp-rocm-6.1.1/include/rppi.h <==
/*
Copyright (c) 2019 - 2023 Advanced Micro Devices, Inc. All rights reserved.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

#ifndef RPPI_H
#define RPPI_H

/*!
 * \file
 * \brief RPP Image Operations - To be deprecated
 * \defgroup group_rppi RPP Image Operations
 * \brief The header includes all files containing RPP Image Operations - To be deprecated
 * \deprecated
 */

#include "rpp.h"
#ifdef __cplusplus
extern "C" {
#endif

#include "rppi_image_augmentations.h"
#include "rppi_arithmetic_operations.h"
#include "rppi_color_model_conversions.h"
#include "rppi_filter_operations.h"
#include "rppi_geometry_transforms.h"
#include "rppi_logical_operations.h"
#include "rppi_statistical_operations.h"
#include "rppi_morphological_transforms.h"
#include "rppi_computer_vision.h"
#include "rppi_fused_functions.h"
#include "rppi_advanced_augmentations.h"

#ifdef __cplusplus
}
#endif

#endif /* RPPI_H */

==> rpp-6.3.3.tar.gz: rpp-rocm-6.3.3/include/rppi.h <==
/*
MIT License

Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

#ifndef RPPI_H
#define RPPI_H

/*!
 * \file
 * \brief RPP Image Operations - To be deprecated
 * \defgroup group_rppi RPP Image Operations
 * \brief The header includes all files containing RPP Image Operations - To be deprecated
 * \deprecated
 */

#include "rpp.h"
#ifdef __cplusplus
extern "C" {
#endif

#include "rppi_image_augmentations.h"
#include "rppi_arithmetic_operations.h"
#include "rppi_color_model_conversions.h"
#include "rppi_filter_operations.h"
#include "rppi_geometry_transforms.h"
#include "rppi_logical_operations.h"
#include "rppi_statistical_operations.h"
#include "rppi_morphological_transforms.h"
#include "rppi_computer_vision.h"
#include "rppi_fused_functions.h"
#include "rppi_advanced_augmentations.h"

#ifdef __cplusplus
}
#endif

#endif /* RPPI_H */
